#!/bin/sh

KOJONEY_PATH=/usr/share/kojoney

echo Kojoney Honeypot installer. 
echo
echo Press enter to view the license agreement ...
read
more LICENSE

echo -e "Do you accept the license terms (yes/no) ?"
read license_accept

if [ $license_accept = 'yes' ]; then
	echo GPL version 2 license accepted.
	echo
else
	echo You need to accept the license to install it.
	echo Exitting...
	echo
	exit
fi

if [ -d $KOJONEY_PATH ]; then
	echo Directory exists. Uninstall it first.
	echo Exitting...
	exit
else
	echo Creating directory $KOJONEY_PATH
	mkdir $KOJONEY_PATH
fi

if [ -d /etc/kojoney ]; then
	echo WARNING! Directory /etc/kojoney exists!
else
	echo Creating directory /etc/kojoney
	mkdir /etc/kojoney
fi

echo Copying vital files to $KOJONEY_PATH and /etc/kojoney
cp *.py* $KOJONEY_PATH
cp fake_users /etc/kojoney
echo

echo Copying report tools to $KOJONEY_PATH
cp -f reports/* $KOJONEY_PATH
echo

temp_dir=`mktemp -d`
echo Copying IP-Country Perl Library to temporary directory $temp_dir
cp -f reports/ip_country/* $temp_dir

echo Entering directory
old_dir=`pwd`
cd $temp_dir

echo Unpacking IP-Country Perl Library ...
tar -xvzf *.tar.gz
echo Entering directory ...
cd IP*

echo Configuring extension 
perl Makefile.PL

echo Making extension
make

echo Testing the extension
make test

echo Installing extension
make install

echo Ok, extension installed. Continuing.
cd $old_dir
rm -fr $temp_dir

echo Copying man pages
cp docs/man/* /usr/local/man/man1/

echo Making $KOJONEY_PATH/kojoney.py executable
chmod u+x $KOJONEY_PATH/kojoney.py
echo

echo Creating symlinks
ln -s $KOJONEY_PATH/kojoney.py /usr/bin/kojoneyd
ln -s $KOJONEY_PATH/kojreport /usr/bin/kojreport
ln -s $KOJONEY_PATH/kojreport-filter /usr/bin/kojreport-filter
ln -s $KOJONEY_PATH/kip2country /usr/bin/kip2country
echo

echo "Do you want to run it automatically at boot time (yes/no)? "
read res

if [ $res != 'yes' ]; then
	echo "Skipping System V script installation"
else
	echo Copying startup script
	cp init.d/* /etc/init.d/
	echo "**********************************************************"
	echo No run levels were assigned. You need to do this manually.
	echo "**********************************************************"
fi

echo
echo Ok. Kojoney is installed.
echo You can run it by typing either '/usr/bin/kojoneyd' or '/etc/init.d/kojoney start'
echo
